@@ -211,9 +211,6 @@ class PW:
 
         :param name: The name of the attribute to proxy.
         """
-        if hasattr(self, name):
-            return getattr(self, name)
-
         if self.p is not None:
             return getattr(self.p, name)
         elif self.r is not None:
